Documentation
¶
Overview ¶
package parser allows extract elements from a query string and create Input object required for GNames faceted search.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Parser ¶
type Parser interface {
// ParseQuery takes a query string, parses it, registers warnings if
// query is not well-formed, and packs received data into a search.Input
// object.
ParseQuery(q string) search.Input
// Debug takes a query string, parses it, and prints aot an abstract
// syntax tree of the parsed result. This method is used for developing
// and debuging the parser behavior.
Debug(string)
}
Parser contains methods for parsing a faceted search query for GNames.
Click to show internal directories.
Click to hide internal directories.